Index: /trunk/MagicSoft/Mars/msignal/MExtractBlindPixel.cc
===================================================================
--- /trunk/MagicSoft/Mars/msignal/MExtractBlindPixel.cc	(revision 4387)
+++ /trunk/MagicSoft/Mars/msignal/MExtractBlindPixel.cc	(revision 4388)
@@ -29,14 +29,27 @@
 //  Extracts the signal from a fixed window in a given range.
 //
 //  Call: SetRange(fHiGainFirst, fHiGainLast, fLoGainFirst, fLoGainLast) 
 //  to modify the ranges. The "lo-gain" ranges are used for the NSB rejection 
 //  whereas the high-gain ranges for blind pixel signal extraction. "High-gain" 
 //  ranges can extend to the slices stored as "low-gain" in MRawEvtPixelIter
 //  Defaults are: 
 // 
 //   fHiGainFirst =  fgHiGainFirst =  12 
 //   fHiGainLast  =  fgHiGainLast  =  16
 //   fLoGainFirst =  fgLoGainFirst =  0 
 //   fLoGainLast  =  fgLoGainLast  =  10
 //
 //////////////////////////////////////////////////////////////////////////////
@@ -68,5 +81,5 @@
 const Byte_t  MExtractBlindPixel::fgHiGainLast       =  29;
 const Byte_t  MExtractBlindPixel::fgLoGainFirst      =   0;
-const Byte_t  MExtractBlindPixel::fgLoGainLast       =   6;
+const Byte_t  MExtractBlindPixel::fgLoGainLast       =   7;
 const Int_t   MExtractBlindPixel::fgNSBFilterLimit   =  70;
 const Float_t MExtractBlindPixel::fgResolution       = 0.003;
@@ -329,6 +342,7 @@
 
   *fLog << endl;
-  *fLog << inf << GetDescriptor() << ": Taking " << range
-        << " FADC samples from " 
+  *fLog << inf << GetDescriptor() << ": Extracting " 
+	<< Form("%s",IsExtractionType(kAmplitude) ? "Amplitude " : " Integral ")
+	<< " using " << range << " FADC samples from " 
         << Form("%s%2i",fHiLoFirst ? "Low Gain slice " : " High Gain slice ",
                 fHiLoFirst ? (Int_t)fHiLoFirst : (Int_t)fHiGainFirst) 
@@ -337,5 +351,9 @@
                 fHiLoLast ?  (Int_t)fHiLoLast-1 : (Int_t)fHiGainLast ) 
         << endl;
-
+  if (IsExtractionType(kFilter))
+    *fLog << inf << GetDescriptor() << ": Will use Filter using " 
+	  << (Int_t)(fLoGainLast-fLoGainFirst+1) << " FADC slices " 
+	  << "from High Gain slice " << (Int_t)fLoGainFirst 
+	  << " to High Gain slice " << (Int_t)fLoGainLast << endl;
 
   fBlindPixel->SetUsedFADCSlices(fHiGainFirst, range);
@@ -29,14 +29,27 @@
 //  Extracts the signal from a fixed window in a given range.
 //
-//  Call: SetRange(fHiGainFirst, fHiGainLast, fLoGainFirst, fLoGainLast) 
-//  to modify the ranges. The "lo-gain" ranges are used for the NSB rejection 
-//  whereas the high-gain ranges for blind pixel signal extraction. "High-gain" 
-//  ranges can extend to the slices stored as "low-gain" in MRawEvtPixelIter
-//  Defaults are: 
-// 
-//   fHiGainFirst =  fgHiGainFirst =  12 
-//   fHiGainLast  =  fgHiGainLast  =  16
-//   fLoGainFirst =  fgLoGainFirst =  0 
-//   fLoGainLast  =  fgLoGainLast  =  10
+//  Before run 31693 (gkModificationRun):
+//
+//    Call: SetRange(fHiGainFirst, fHiGainLast, fLoGainFirst, fLoGainLast) 
+//    to modify the ranges. The "low-gain" ranges are used for the NSB rejection 
+//    whereas the high-gain ranges for blind pixel signal extraction. "High-gain" 
+//    ranges can extend to the slices stored as "low-gain" in MRawEvtPixelIter
+//
+//    Defaults are: 
+// 
+//     fHiGainFirst =  fgHiGainFirst =  10 
+//     fHiGainLast  =  fgHiGainLast  =  29
+//     fLoGainFirst =  fgLoGainFirst =  0 
+//     fLoGainLast  =  fgLoGainLast  =  7
+//
+//  After run 31693 (gkModificationRun):
+//
+//   Call: SetFirst(), SetLast() to modify the ranges. No filter is applied, 
+//   but instead the signal amplitude is extracted using Cubic spline. 
+// 
+//    Defaults are: 
+// 
+//     fHiGainFirst =  fgFirst =  0 
+//     fHiGainLast  =  fgLast  =  7
 //
 //////////////////////////////////////////////////////////////////////////////
